@@ -1,6 +1,6 @@
 use utf8;
 package CPAN::Testers::Schema::Result::PerlVersion;
-our $VERSION = '0.023';
+our $VERSION = '0.024';
 # ABSTRACT: Metadata about Perl versions
 
 #pod =head1 SYNOPSIS
@@ -135,7 +135,7 @@ CPAN::Testers::Schema::Result::PerlVersion - Metadata about Perl versions
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 SYNOPSIS
 
@@ -203,10 +203,20 @@ on the supplied C<version> field.
 
 L<DBIx::Class::Row>, L<CPAN::Testers::Schema>
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Oriol Soriano <oriolsoriano@gmail.com>
 
+=item *
+
+Doug Bell <preaction@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2018 by Oriol Soriano, Doug Bell.
