@@ -1,6 +1,6 @@
 use utf8;
 package CPAN::Testers::Schema::ResultSet::TestReport;
-our $VERSION = '0.023';
+our $VERSION = '0.024';
 # ABSTRACT: Query the raw test reports
 
 #pod =head1 SYNOPSIS
@@ -128,7 +128,7 @@ CPAN::Testers::Schema::ResultSet::TestReport - Query the raw test reports
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 SYNOPSIS
 
@@ -165,10 +165,20 @@ APIs.
 L<CPAN::Testers::Schema::Result::TestReport>, L<DBIx::Class::ResultSet>,
 L<CPAN::Testers::Schema>
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Oriol Soriano <oriolsoriano@gmail.com>
 
+=item *
+
+Doug Bell <preaction@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2018 by Oriol Soriano, Doug Bell.
